--[[ Azuarc's Level Guide v. 1.5

Azuarc's Level Guide is a simple addon that take's Azuarc's excellent online levelling guide (available at http://wow.allakhazam.com/db/guides.html?guide=963) and presents it in an easy to access format for on-line reference without the need to alt-tab back and forth.
 
The UI is based on Gello's TinyPad, a lightweight notepad mod.  Special thanks to Malcolm Chambers for creating the TinyPadEditor to make entering this data in *much* easier!

Azuarc's level guide is used by permission of Azuarc and Allakhazam.  

NOTE: while the guides are mostly presented in their original form, there are certain places that some comments have been removed for length.  In addition, all of the maps and graphics have been stripped, so first-time users are encouraged to review the original guides before trying to follow the on-line version.
	
]]

-- SavedVariables
AzuarcLGPages = { "" } -- numerically-indexed table of pages
AzuarcLGSettings = {} -- Lock, Font, Chapter, Page
ALGMMBSettings = {} -- hold minimap button settings

AzuarcLG = {

	chapters = {
		"Act 0: Prelude",
		"Act 1: Darkshore (12-15)",
		"Act 2: Bloodmyst/Darkshore (15-20)",
		"Act 3: Ashenvale (20-23)",
		"Act 4: Duskwood (23-27)",
		"Act 5: Ashenvale/Duskwood (27-30)",
		"Act 6: Thousand Needles (30-32)",
		"Act 7: Stranglethorn Vale (32-35)",
		"Act 8: Desolace (35-37)",
		"Act 9: Stranglethorn Vale pt. 2 (37-41)",
		"Act 10: TFH pt. 1 (41-43)",
		"Act 11: Stranglethorn Vale pt. 3 (43-46)",
		"Act 12: TFH pt. 2 (46-50)",
		"Act 13: Un'goro Crater/Plaguelands (51-52)",
		"Act 14: Felwood (53-54)",
		"Act 15: Winterspring / Plaguelands (55-56)",
		"Act 16: Plaguelands (57-59)",
		"Act 17: Hellfire Peninsula east (59-60)",
		"Act 18: Hellfire Peninsula west (61)",
		"Act 19: Zangarmash (62-63)",
		"Act 20: Terokkar Forest (64-65)",
		"Act 21: Nagrand (66)",
		"Act 22: Terokkar Forest (67)",
		"Act 23: Blade's Edge Mountains (68/69)",
	},

	-- tooltip info for controls
	controls = {
		{"ALGDDMenuButton","Select Chapter","Select which chapter of the guide to view."},
		{"AzuarcLGStart","First Scene","Go to first scene"},
		{"AzuarcLGLeft","Back","Go back one scene"},
		{"AzuarcLGRight","Forward","Go forward one scene"},
		{"AzuarcLGEnd","Last Page","Go to the last scene"},
		{"AzuarcLGClose","Close Guide","Close the Azuarc Level Guide"},
		{"AzuarcLGLock","Lock","Lock or Unlock window"},
		{"AzuarcLGFont","Font","Cycle through different fonts"},
		{"AzuarcLGSearch","Options","Search pages for text, change fonts or lock window"},
		{"AzuarcLGSearchNext","Find Next","Find next page with this text"},
		{"AzuarcLGSearchEditBox","Search Criterea","Enter the text to search for here"},
		{"AzuarcLGUndo","Undo","Revert page to last saved text"},
	},

	-- list of fonts to cycle through
	fonts = {
		{"Fonts\\FRIZQT__.TTF",10},
		{"Fonts\\FRIZQT__.TTF",12}, -- default
		{"Fonts\\FRIZQT__.TTF",16},
		{"Fonts\\ARIALN.TTF",12},
		{"Fonts\\ARIALN.TTF",16},
		{"Fonts\\ARIALN.TTF",20},
		{"Fonts\\MORPHEUS.ttf",16,"OUTLINE"},
		{"Fonts\\MORPHEUS.ttf",24,"OUTLINE"}
		-- add fonts here
	},

	current_page = 1, -- page currently viewed
	first_use = 1 -- whether this was used this session
}

-- constants
--[[ ALG_HEX_WHITE = "|cffffffff"; - normal
ALG_HEX_RED = "|cffff0000"; - important note
ALG_HEX_ORANGE = "|cffff7700"; - npc
ALG_HEX_YELLOW = "|cffffff00"; - quest
ALG_HEX_GREEN = "|cff00ff00"; - heading
ALG_HEX_GRAY = "|cff777777"; - item
ALG_HEX_LIGHTBLUE = "|cff77ccff"; - location ]]

BINDING_HEADER_AZUARCLG = "Azuarc's Level Guide"
SLASH_COMMAND_MMB = "MINIMAP"
SLASH_COMMAND_MMB_HELP = "minimap [ON|OFF]"
ALG_NAME = "Azuarc's Leveling Guide"
ALG_ICON = "Interface\\Icons\\INV_Misc_Book_04.png";
ALG_TOC = 20300;

ALG_FUBAR_PREV_PAGE = "<< Previous Scene ";
ALG_FUBAR_NEXT_PAGE = "Next Scene >>";

function AzuarcLG.OnLoad()

	-- register events 
	this:RegisterEvent("VARIABLES_LOADED") -- create buttons anytime after VARIABLES_LOADED
	this:RegisterEvent("PLAYER_LOGIN") -- initialization

	-- set up frame
	this:SetMinResize(236,96)
	table.insert(UISpecialFrames,"AzuarcLGFrame")
	table.insert(UISpecialFrames,"AzuarcLGSearchFrame")

      -- set up slash handler
	SlashCmdList["AZUARCLGSLASH"] = AzuarcLG.SlashHandler
	SLASH_AZUARCLGSLASH1 = "/alg"
	SLASH_AZUARCLGSLASH2 = "/azuarc"

	--- Check for FuBar
	if(IsAddOnLoaded("FuBar")) then
		AzuarcLG:FuBar();
	end
	
end

function AzuarcLG.OnEvent()

	local position
	if event=="PLAYER_LOGIN" then
		AzuarcLGSettings.Font = AzuarcLGSettings.Font or 2
		AzuarcLG.UpdateFont()
		AzuarcLG.UpdateLock()
		out("done with login")
	end
	if ((event=="VARIABLES_LOADED") and (not (IsAddOnLoaded("FuBar")))) then

		-- Set up minimap button
            out("setting up the button")
		local info = {
			icon = ALG_ICON,
			position = 30, -- default only. after first use, SavedVariables used
			drag = "CIRCLE", -- default only. after first use, SavedVariables used
			left = function() AzuarcLG:Toggle() end,
			right = function() MyMinimapButton:SetEnable(ALG_NAME,0) end,
			tooltip = "Left click: Toggle Guide Display\nRight click: Hide minimap Button\n (type '/ALG minimap on' to restore)",
			enabled = 1 -- default only. after first use, SavedVariables used
		}
		out("calling create")
		      MyMinimapButton:Create(ALG_NAME, ALGMMBSettings, info)
		out("button created")
	      
	end

end

-- /alg ? will show help, 
-- /alg minimap on|off will toggle the minimap button,
-- /alg # will go to a page, 
-- /alg alone toggles window
function AzuarcLG.SlashHandler(msg)

	local mmb = strfind(msg, "\?")
	if mmb then  -- help request
		DEFAULT_CHAT_FRAME:AddMessage("Usage: /alg [Pagenumber]|[Minimap ON|OFF]")
	else
		local uppermsg = strupper(msg)
		local mmb = strfind(uppermsg, SLASH_COMMAND_MMB)
		if mmb then 
			out("saw the minimap button command")
			out("mmb = " .. mmb)
			out("SLASH_COMMAND_MMB = " .. SLASH_COMMAND_MMB)
			out("tonumber(mmb) = " .. tonumber(mmb))
			out("len = " .. strlen(SLASH_COMMAND_MMB))
			local parmpos = tonumber(mmb)+strlen(SLASH_COMMAND_MMB)
			mmb = strfind(uppermsg, "ON", parmpos)
			if mmb then
				out("saw the minimap button 'ON' command")
				MyMinimapButton:SetEnable(ALG_NAME,1)
			else 
				mmb = strfind(uppermsg, "OFF", parmpos)
				if mmb then
					out("saw the minimap button 'OFF' command")
					MyMinimapButton:SetEnable(ALG_NAME,0)
				else
					DEFAULT_CHAT_FRAME:AddMessage("AzuarcLG: Incorrect option for minimap button - must be 'ON' or 'OFF'")

				end 
			end
		else -- not the minimap button command
 			local _,_,page = strfind(msg or "","(%d+)")
			if page then   -- found the page number 
				page = tonumber(page)
				if AzuarcLGPages[page] then
					AzuarcLG.current_page = page
					AzuarcLG.ShowPage(true)
				else
					DEFAULT_CHAT_FRAME:AddMessage("AzuarcLG: Page "..page.." doesn't exist.")
				end
			else -- no parms, just toggle the display
				AzuarcLG.Toggle()
			end
		end 	
	end
end

-- toggles window on/off screen
function AzuarcLG.Toggle()
	if AzuarcLGFrame:IsVisible() then
		AzuarcLGFrame:Hide()
	else
		AzuarcLGFrame:Show()
	end
end

-- window movement
function AzuarcLG.StartMoving()
	if arg1=="LeftButton" and not AzuarcLGSettings.Lock then
		AzuarcLGFrame:StartMoving()
	end
end

function AzuarcLG.StopMoving()
	if arg1=="LeftButton" then
		AzuarcLGFrame:StopMovingOrSizing()
	end
end

function AzuarcLG.Tooltip()
	local which = this:GetName()
	for i in pairs(AzuarcLG.controls) do
		if AzuarcLG.controls[i][1]==which then
			GameTooltip_SetDefaultAnchor(GameTooltip,UIParent)
			GameTooltip:AddLine(AzuarcLG.controls[i][2])
			GameTooltip:AddLine(AzuarcLG.controls[i][3],.85,.85,.85,1)
			GameTooltip:Show()
			break
		end
	end
end

-- Titlebar button clicks
function AzuarcLG.OnClick()
	local which = this:GetName()

	if which=="AzuarcLGUndo" then
		AzuarcLGEditBox:SetText(AzuarcLGPages[AzuarcLG.current_page])
	end
	if which=="ALGDDMenuButton" then
    		ToggleDropDownMenu(1, nil, ALGDropDownMenu, ALGDDMenuButton, 0, 0);
	elseif which=="AzuarcLGStart" then
		AzuarcLG.ChangeIfNew(1, true)
	elseif which=="AzuarcLGLeft" then
		AzuarcLG.GetPreviousPage(AzuarcLGPages, true)
	elseif which=="AzuarcLGRight" then
		AzuarcLG.GetNextPage(AzuarcLGPages, true)
	elseif which=="AzuarcLGEnd" then
		AzuarcLG.ChangeIfNew(table.getn(AzuarcLGPages), true)
	elseif which=="AzuarcLGClose" then
		AzuarcLGFrame:Hide()
	elseif which=="AzuarcLGLock" then
		AzuarcLGSettings.Lock = not AzuarcLGSettings.Lock
		AzuarcLG.UpdateLock()
	elseif which=="AzuarcLGFont" then
		AzuarcLGSettings.Font = AzuarcLGSettings.Font+1
		AzuarcLG.UpdateFont()
	elseif which=="AzuarcLGSearch" then
		if AzuarcLGSearchFrame:IsVisible() then
			AzuarcLGSearchFrame:Hide()
		else
			AzuarcLGSearchFrame:Show()
		end
	elseif which=="AzuarcLGSearchNext" then
		AzuarcLG.DoSearch()
	end

end

-- disables/enables page movement buttons depending on page
function AzuarcLG.ValidateButtons()

	-- nil for disabled, 1 for enabled
	local function set_state(button,enabled)
		if enabled then
			button:SetAlpha(1);
			button:Enable()
		else
			button:SetAlpha(.5);
			button:Disable()
		end
	end 
	
	set_state(AzuarcLGStart,1)
	set_state(AzuarcLGLeft,1)
	set_state(AzuarcLGRight,1)
	set_state(AzuarcLGEnd,1)

	if AzuarcLG.current_page==1 then
		set_state(AzuarcLGStart)
		set_state(AzuarcLGLeft)
	end
	if AzuarcLG.current_page==table.getn(AzuarcLGPages) then
		set_state(AzuarcLGRight)
		set_state(AzuarcLGEnd)
	end
end

function AzuarcLG.GetNextPage(book, isShown)
	if not AzuarcLG.current_page then
		AzuarcLG.current_page = 0
	end		
	out("get next " .. math.min(AzuarcLG.current_page+1,table.getn(book)))
	AzuarcLG.ChangeIfNew(math.min(AzuarcLG.current_page+1,table.getn(book)), isShown)
end

function AzuarcLG.GetPreviousPage(book, isShown)
	if not AzuarcLG.current_page then
		AzuarcLG.current_page = 0
	end		
	AzuarcLG.ChangeIfNew(math.max(AzuarcLG.current_page-1,1), isShown)
end

function AzuarcLG.ChangeIfNew(newpage, showpage)
	out("curr page =  " .. AzuarcLG.current_page);
	out("newpage " .. newpage);
	if (newpage == AzuarcLG.current_page) then
		-- nothing
	else
		out("showing page: " .. newpage)
		AzuarcLG.current_page = newpage;
		AzuarcLG.ShowPage(showpage)
	end
end

-- shows/updates the current page
function AzuarcLG.ShowPage(isShown)
	if (isShown and not AzuarcLGFrame:IsVisible()) then
		AzuarcLGFrame:Show()
	end
	if AzuarcLGPages[AzuarcLG.current_page] then
		AzuarcLGPageNum:SetText(AzuarcLG.current_page)
		AzuarcLGEditBox:SetText(AzuarcLGPages[AzuarcLG.current_page])
		AzuarcLG.ValidateButtons()
	end
end

-- refreshes window when shown
function AzuarcLG.OnShow()
	AzuarcLG.FirstUseCheck()
	AzuarcLG.ShowPage(true)
	AzuarcLGEditBox:SetWidth(AzuarcLGFrame:GetWidth()-50)
end

-- saves page when window hides
function AzuarcLG.OnHide()
	AzuarcLGPages[AzuarcLG.current_page] = AzuarcLGEditBox:GetText()
	AzuarcLGSettings.Page = AzuarcLG.current_page
	AzuarcLGUndo:Disable()
	AzuarcLGEditBox:ClearFocus()
end

-- changes border and resize grip depending on lock status
function AzuarcLG.UpdateLock()
	if AzuarcLGSettings.Lock then
		AzuarcLGFrame:SetBackdropBorderColor(0,0,0,1)
		AzuarcLGSearchFrame:SetBackdropBorderColor(0,0,0,1)
		AzuarcLGResizeGrip:Hide()
	else
		AzuarcLGFrame:SetBackdropBorderColor(1,1,1,1)
		AzuarcLGSearchFrame:SetBackdropBorderColor(1,1,1,1)
		AzuarcLGResizeGrip:Show()
	end
	AzuarcLG.MakeESCable("AzuarcLGFrame",AzuarcLGSettings.Lock)
end

-- updates EditBox font to current settings
function AzuarcLG.UpdateFont()
	if AzuarcLGSettings.Font > table.getn(AzuarcLG.fonts) then
		AzuarcLGSettings.Font = 1
	end
	local font = AzuarcLGSettings.Font
	AzuarcLGEditBox:SetFont(AzuarcLG.fonts[font][1],AzuarcLG.fonts[font][2],AzuarcLG.fonts[font][3])
end

-- adds frame to UISpecialFrames, removes frame if disable true
function AzuarcLG.MakeESCable(frame,disable)
	local idx
	for i=1,table.getn(UISpecialFrames) do
		if UISpecialFrames[i]==frame then
			idx = i
			break
		end
	end
	if idx and disable then
		table.remove(UISpecialFrames,idx)
	elseif not idx and not disable then
		table.insert(UISpecialFrames,1,frame)
	end
end
	
-- when search summoned, remove ESCability of main window (only search cleared with ESC)
function AzuarcLG.SearchOnShow()
	AzuarcLG.MakeESCable("AzuarcLGFrame","disable")
end

-- when search dismissed, restore ESCability to main window and reset search elements
function AzuarcLG.SearchOnHide()
	if not AzuarcLGSettings.Lock then
		AzuarcLG.MakeESCable("AzuarcLGFrame")
	end
	AzuarcLGSearchResults:SetText("Search:")
	AzuarcLGSearchEditBox:ClearFocus()
end

-- does a count
function AzuarcLG.SearchEditBoxOnChange()
	local search = string.lower(AzuarcLGSearchEditBox:GetText() or "")
	if string.len(search)<1 then
		AzuarcLGSearchResults:SetText("Search:")
	else
		local count = 0
		for i=1,table.getn(AzuarcLGPages) do
			count = count + (string.find(string.lower(AzuarcLGPages[i]),search,1,1) and 1 or 0)
		end
		AzuarcLGSearchResults:SetText(count.." found")
	end
end

-- performs a search for the text in the search box
function AzuarcLG.DoSearch()
	local search = string.lower(AzuarcLGSearchEditBox:GetText() or "")
	if string.len(search)<1 then
		return
	end
	local page = AzuarcLG.current_page
	for i=1,table.getn(AzuarcLGPages) do
		page = page + 1
		if page > table.getn(AzuarcLGPages) then
			page = 1
		end
		if string.find(string.lower(AzuarcLGPages[page]),search,1,1) then
			AzuarcLGPages[AzuarcLG.current_page] = AzuarcLGEditBox:GetText()
			AzuarcLG.current_page = page
			AzuarcLG.ShowPage(true)
			return
		end
	end
end

function AzuarcLG.OnTextChanged()
	local scrollBar = getglobal(this:GetParent():GetName().."ScrollBar")
	this:GetParent():UpdateScrollChildRect()
	local min, max = scrollBar:GetMinMaxValues()
	if ( max > 0 and (this.max ~= max) ) then
		this.max = max
		scrollBar:SetValue(max)
	end
	if this:GetText()~=AzuarcLGPages[AzuarcLG.current_page] then
		AzuarcLGUndo:Enable()
	else
		AzuarcLGUndo:Disable()
	end
end

function AzuarcLG.LoadChapterForFrame()

        local selectedItem = this.value
	out("Calling LoadChapter for " .. selectedItem)
	AzuarcLGSettings.LastChapter = selectedItem
	out("Last chapter now " .. AzuarcLGSettings.LastChapter)
	AzuarcLG.LoadChapter(true)		

end

function AzuarcLG.LoadChapter(showIt)

	-- Load up this chapter
	out("Loading chapter: " .. AzuarcLGSettings.LastChapter)
	AzuarcLGPages = ALGChapters[AzuarcLGSettings.LastChapter] 
	AzuarcLG.current_page = 1
	AzuarcLG.ShowPage(showIt)

end

function ALGDropDownMenu_OnLoad()

	local currentChapter = AzuarcLGSettings.LastChapter;
	local info = UIDropDownMenu_CreateInfo(); 

	for i in pairs(AzuarcLG.chapters) do
		info.text = AzuarcLG.chapters[i];
		info.value = i-1;
       		info.func  = AzuarcLG.LoadChapterForFrame;
		info.owner = this:GetParent();
	 	info.checked = (currentChapter == (i-1));
	        UIDropDownMenu_AddButton(info);
	end 	
end

function AzuarcLG.FirstUseCheck()

	if AzuarcLG.first_use then
		-- only when the pad is first shown 
		AzuarcLG.current_page = 1
		if AzuarcLGSettings.Page then
			-- use saved page value if available 
			AzuarcLG.current_page = AzuarcLGSettings.Page 
		end
	end 
	AzuarcLG.first_use = nil
end

function out(text)
  -- DEFAULT_CHAT_FRAME:AddMessage(text)
  -- UIErrorsFrame:AddMessage(text, 1.0, 1.0, 0, 1, 10) 
end

--- FuBar Support
function AzuarcLG:FuBar()

	local tablet = AceLibrary("Tablet-2.0")
	AzuarcLGFu = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "FuBarPlugin-2.0")
	AzuarcLGFu.hasIcon = ALG_ICON
	AzuarcLGFu.name = ALG_NAME
	AzuarcLGFu.title = ALG_NAME
	-- AzuarcLGFu.version = METAHUD_VERSION
	AzuarcLGFu.category = "Miscellaneous"
 	AzuarcLGFu.clickableTooltip = true

	AzuarcLGFu.OnMenuRequest = {
		type = 'group',
		args = {
			chapter = {
				type = 'text',
				name = 'Select Act',
				desc = 'Current Act to display in Tooltip',
				validate = AzuarcLG.chapters,
				get = function() return AzuarcLG.chapters[AzuarcLGSettings.LastChapter+1] end,
				set = function(v) 
						AzuarcLGFu:GetIndexFromChapterText(v) 
					end,
				order=10,
			},
			tipwidth = {
				type = 'range',
			        name = 'Tooltip Width',
			    	desc = "Set tooltip width (chars)",
			    	get = function() return AzuarcLGFu:GetTooltipWidth() end,
			    	set = function(v) AzuarcLGFu:SetTooltipWidth(v) end,
			    	min = 50,
			    	max = 400, 
			    	step = 1, 
				order=20,
			},
			textsize = {
			    	type = 'range',
		          	name = 'Guide Text Size',
			    	desc = "Set Font Size for guide text",
			    	get = function() return AzuarcLGFu:GetTextFontSize() end,
			    	set = function(v) AzuarcLGFu:SetTextFontSize(v) end,
			    	min = 8,
			    	max = 20, 
			    	step = 1, 
				order=30,
			},
		}
	} 

	AzuarcLGFu:RegisterDB("AzuarcLGFuDB")


	function AzuarcLGFu:OnInitialize()
		-- if we're FuBar'ing, we turn off built-in minimap support
		MyMinimapButton:SetEnable(ALG_NAME,0);
	end

	function AzuarcLGFu:SetTooltipWidth(var)
	    AzuarcLGFuDB.TooltipWidth = var;
	    out("SetTooltipWidth: tooltip width now = " .. AzuarcLGFuDB.TooltipWidth);
        end


	function AzuarcLGFu:GetTextFontSize()
	    local var = AzuarcLGFuDB.TextFontSize; 
            if not var then
		var = 12;
            end
            return var
	end

	function AzuarcLGFu:SetTextFontSize(var)
	    AzuarcLGFuDB.TextFontSize= var;
	    out("TextFontSize: font size now = " .. AzuarcLGFuDB.TextFontSize);
        end


	function AzuarcLGFu:GetTooltipWidth()
	    local var = AzuarcLGFuDB.TooltipWidth; 
            if not var then
		var = 100;
            end
            return var
	end

	function AzuarcLGFu:OnClick(button)
		if(button == "LeftButton") then
			AzuarcLG:Toggle()
		end
	end

	function AzuarcLGFu:OnTooltipUpdate()

		AzuarcLG.FirstUseCheck()
		
		local prevBlue = 1
		if AzuarcLG.current_page == 1 then
			prevBlue = 0
		end
		local nextBlue = 1
		if AzuarcLG.current_page == table.getn(AzuarcLGPages) then
			nextBlue = 0
		end

		cat = tablet:AddCategory(
			"text", "Controls",
			"hideBlankLine", true,
			"size", 12,
			"columns", 1
		)
		cat:AddLine("text", ALG_FUBAR_PREV_PAGE,
				"textR", 0,
				"textG", 0,
				"textB", prevBlue,
				"size", 10,
		  	    	"func", function() AzuarcLG.GetPreviousPage(AzuarcLGPages, false) end);
		cat:AddLine("text", ALG_FUBAR_NEXT_PAGE,
				"textR", 0,
				"textG", 0,
				"textB", nextBlue, 
				"size", 10,
		  	    "func", function() AzuarcLG.GetNextPage(AzuarcLGPages, false) end);

		if not AzuarcLGSettings.LastChapter then
			AzuarcLGSettings.LastChapter = 0
		end		
		local chapterName = AzuarcLG.chapters[AzuarcLGSettings.LastChapter+1];

		cat = tablet:AddCategory(
			"text", chapterName,
			"hideBlankLine", true,
			"columns", 1,
			"textR", 0,
			"textG", 1,
			"textB", 0,
			"size", 14,
			"child_size" , AzuarcLGFuDB.TextFontSize,
			"child_textR", 1,
			"child_textG", 1,
			"child_textB", 1
		)

		out("OnTooltipUpdate: tooltip width now = " .. AzuarcLGFu:GetTooltipWidth());
		-- Hack to set width until I can find a better way
		cat:AddLine("text", AzuarcLGPages[AzuarcLG.current_page],
				"wrap", true)

		local spacer = string.rep(" ", AzuarcLGFu:GetTooltipWidth()-1)
		cat:AddLine("text", spacer .. ".")
		tablet:SetHint("Left Click to toggle display of guide control panel")

		-- Save last shown page
		AzuarcLGSettings.Page = AzuarcLG.current_page

	end

	function AzuarcLGFu:GetIndexFromChapterText(chapterTitle)

		out("looking for text = " .. chapterTitle) 
		local currentChapter = AzuarcLGSettings.LastChapter;
		
		for i in pairs(AzuarcLG.chapters) do
			out("comparing to " .. AzuarcLG.chapters[i]) 
			if (AzuarcLG.chapters[i] == chapterTitle) then
				out("found");
				currentChapter = i-1;
				break
			end
		end
		out("setting AzuarcLGSettings.LastChapter to " .. currentChapter) 
		AzuarcLGSettings.LastChapter = currentChapter ;
		AzuarcLG.LoadChapter(false)
	end
end
